==> noname-snapshot-1998.12.23.tar.gz: noname/observe.py <==
""" observe.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

import sys, os, time
import ilu
sys.path.append('/usr/local/lib/python/sylu')
from types import *
from engine import engine,factory
from event import *
from map import map

def get_engine(factoryObjectSID, factoryObjectIH):
    # We have to call ilu.LookupObject() with the object ID of
    # the factory object, and the "type" of the object we're looking
    # for, which is always available as MODULE.TYPENAME

    f = ilu.LookupObject (factoryObjectSID, factoryObjectIH, factory)
    if not f:
        print "Can't find factory instance "+factoryObjectSID+"/"+factoryObjectIH
        sys.exit(1)
    c = f.createEngine()
    return (c)

def sc(x,min,max,s):
    res=int(s/(max-min)*(x-min))
    if res<0: res=0
    if res>=s: res=s-1
    return res

class observe:
    def __init__(self, remote, map_add=None, map_del=None):
        if map_add: self.map_add=map_add
        if map_del: self.map_del=map_del
        self.event_dict={}
        if remote:
            self.eng=get_engine("cyphesis","engine")
        else:
            self.eng = engine()
        if not self.eng:
            error("Couldn't create engine")
        self.m=map()
        self.process_events(self.msg("event('load',what='default')"))
    def msg(self,str):
        return eval(self.eng.event(str))
    def run(self, steps=1, display=1):
        if display: print chr(27)+"c"
        res=[]
        for i in range(steps):
            res=self.msg("event('step')")
            self.m.time_str=self.msg("event('time')")[-1].what
            self.process_events(res)
            if display: self.display_text_screen()
            else: print res
        return res
    def dsp(self, steps=1):
        self.run(steps,1)
    def text(self, steps=1):
        self.run(steps,0)
        print self.m.time_str
    #Handle events (method name is: e.command+"_event")
    def fire_event(self,e): pass #this will be removed soon
    def say_event(self,e): pass #no action for now
    def make_event(self, e):
        if not self.m.things.has_key(e.what.id):
            t=self.m.make_thing_from_event(e)
            self.graphics("add",t)
    def move_event(self, e):
        t=self.m.things[e.what]
        self.graphics("del",t)
        if type(e.loc)==TupleType:
            t.xyz=e.loc
        else:
            t.xyz=None
            t.place=self.m.things[e.loc]
        self.graphics("add",t)
    def destroy_event(self, e):
        self.graphics("del",self.m.things[e.what])
        del self.m.things[e.what]
    def undefined_event(self,e):
        print "Undefined:",`e`
        time.sleep(10)
    def process_events(self, events):
        #print events
        for e in events:
            get_event_func(self,e)(e)
    def display_text_screen(self):
        wait=0.0
        xmin=-300.0
        xmax=-xmin
        ymin=-150.0
        ymax=-ymin
        sizex=70
        sizey=20
        def scx(x, min=xmin, max=xmax, s=sizex): return sc(x,min,max,s)
        def scy(y, min=ymin, max=ymax, s=sizey): return sc(y,min,max,s)
        screen = [None]*sizex
        for i in range(sizex):
            screen[i] = ['.'] * sizey
        smithy_list=[]
        home_list=[]
        mind_list=[]
        fire_list=[]
        for t in self.m.things.values():
            if t.name=="smithy": smithy_list.append(t)
            elif t.type=="thing.home": home_list.append(t)
            elif t.type=="thing.mind": mind_list.append(t)
            elif t.name=="fire": fire_list.append(t)
        print chr(27)+"[H",self.m.time_str,"Count of minds:",len(mind_list)
        for t in smithy_list:
            (x,y,z)=t.get_xyz()
            screen[scx(x)][scy(y)]='s'
        for t in home_list:
            (x,y,z)=t.get_xyz()
            screen[scx(x)][scy(y)]='h'
        for m in mind_list:
            (x,y,z)=m.get_xyz()
            x,y=scx(x),scy(y)
            screen[x][y]=m.name[0]
            screen[x+1][y]=m.name[-1]
            #CHEAT!: need way to ask minds about things
            #if m.name[0]=='f' and not m.things.has_key('axe'):
            #    screen[x+2][y]='!'
            #    wait=0.3
            #if not mgoal.have_home(m):
            #    screen[x+2][y]='?'
            #    wait=2.0
        for t in fire_list:
            (x,y,z)=t.get_xyz()
            screen[scx(x)][scy(y)]='F'
            wait=1.0
        out=[]
        for y in range(sizey):
            for x in range(sizex):
                out.append(screen[x][y])
            out.append('\n')
        print string.join(out,'')
        time.sleep(wait)
    def graphics(self, command, thing):
        (x,y,z)=thing.get_xyz()
        #print command,thing.name,x,y,z
        try:
            if command=="add": self.map_add(thing.name,x,y,z)
            elif command=="del": self.map_del(thing.name,x,y,z)
        except AttributeError: pass

==> noname-snapshot-1999.01.11.tar.gz: noname/observe.py <==
""" observe.py
 Copyright (C) 1998 Aloril
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""

import sys, os, time
import ilu
sys.path.append('/usr/local/lib/python/sylu')
from types import *
from engine import engine,factory
from event import *
from mem_map import mem_map

def get_engine(factoryObjectSID, factoryObjectIH):
    # We have to call ilu.LookupObject() with the object ID of
    # the factory object, and the "type" of the object we're looking
    # for, which is always available as MODULE.TYPENAME

    f = ilu.LookupObject (factoryObjectSID, factoryObjectIH, factory)
    if not f:
        print "Can't find factory instance "+factoryObjectSID+"/"+factoryObjectIH
        sys.exit(1)
    c = f.createEngine()
    return (c)

def sc(x,min,max,s):
    res=int(s/(max-min)*(x-min))
    if res<0: res=0
    if res>=s: res=s-1
    return res

class observe:
    def __init__(self, remote, map_add=None, map_del=None):
        if map_add: self.map_add=map_add
        if map_del: self.map_del=map_del
        self.event_dict={}
        if remote:
            self.eng=get_engine("cyphesis","engine")
        else:
            self.eng = engine()
        if not self.eng:
            error("Couldn't create engine")
        self.m=mem_map()
        self.process_events(self.msg("event('load',what='default',loc='debug')"))
    def msg(self,str):
        return eval(self.eng.event(str))
    def run(self, steps=1, display=1):
        if display: print chr(27)+"c"
        res=[]
        for i in range(steps):
            res=self.msg("event('step')")
            self.m.time_str=self.msg("event('time')")[-1].what
            self.process_events(res)
            if display: self.display_text_screen()
            else: print res
        return res
    def dsp(self, steps=1):
        self.run(steps,1)
    def text(self, steps=1):
        self.run(steps,0)
        print self.m.time_str
    #Handle events (method name is: e.command+"_event")
    def fire_event(self,e): pass #this will be removed soon
    def say_event(self,e): pass #no action for now
    def make_event(self, e):
        if not self.m.things.has_key(e.what.id):
            t=self.m.make_thing_from_event(e)
            self.graphics("add",t)
    def move_event(self, e):
        t=self.m.things[e.what]
        self.graphics("del",t)
        if type(e.loc)==TupleType:
            t.xyz=e.loc
        else:
            t.xyz=None
            t.place=self.m.things[e.loc]
        self.graphics("add",t)
    def destroy_event(self, e):
        self.graphics("del",self.m.things[e.what])
        del self.m.things[e.what]
    def sight_event(self,e):
        self.process_events([e.what])
    def imaginary_event(self,e): pass
    def change_event(self,e): pass
    def extinguish_event(self,e): pass
    def undefined_event(self,e):
        print "Undefined:",`e`
        time.sleep(10)
    def process_events(self, events):
        #print events
        for e in events:
            get_event_func(self,e)(e)
    def display_text_screen(self):
        wait=0.0
        xmin=-300.0
        xmax=-xmin
        ymin=-150.0
        ymax=-ymin
        sizex=70
        sizey=20
        def scx(x, min=xmin, max=xmax, s=sizex): return sc(x,min,max,s)
        def scy(y, min=ymin, max=ymax, s=sizey): return sc(y,min,max,s)
        screen = [None]*sizex
        for i in range(sizex):
            screen[i] = ['.'] * sizey
        smithy_list=[]
        home_list=[]
        mind_list=[]
        fire_list=[]
        for t in self.m.things.values():
            if t.name=="smithy": smithy_list.append(t)
            elif t.name=="house": home_list.append(t)
            elif t.type=="thing.body": mind_list.append(t)
            elif t.name=="fire": fire_list.append(t)
        print chr(27)+"[H",self.m.time_str,"Count of minds:",len(mind_list)
        for t in smithy_list:
            (x,y,z)=t.get_xyz()
            screen[scx(x)][scy(y)]='s'
        for t in home_list:
            (x,y,z)=t.get_xyz()
            screen[scx(x)][scy(y)]='h'
        for m in mind_list:
            (x,y,z)=m.get_xyz()
            x,y=scx(x),scy(y)
            screen[x][y]=m.name[0]
            screen[x+1][y]=m.name[-1]
            #CHEAT!: need way to ask minds about things
            #if m.name[0]=='f' and not m.things.has_key('axe'):
            #    screen[x+2][y]='!'
            #    wait=0.3
            #if not mgoal.have_home(m):
            #    screen[x+2][y]='?'
            #    wait=2.0
        for t in fire_list:
            (x,y,z)=t.get_xyz()
            screen[scx(x)][scy(y)]='F'
            wait=1.0
        out=[]
        for y in range(sizey):
            for x in range(sizex):
                out.append(screen[x][y])
            out.append('\n')
        print string.join(out,'')
        time.sleep(wait)
    def graphics(self, command, thing):
        (x,y,z)=thing.get_xyz()
        #print command,thing.name,x,y,z
        try:
            if command=="add": self.map_add(thing.name,x,y,z)
            elif command=="del": self.map_del(thing.name,x,y,z)
        except AttributeError: pass
